Module condition

Module condition 

Condition Argument Validation

Provides general condition validation functionality.

Functions

check_argument
Check if an argument condition is true
check_argument_fmt
Check if an argument condition is true and use formatted message
check_argument_with_message
Check if an argument condition is true and provide a custom error message
check_bounds
Check boundary conditions
check_element_index
Check if an index is within valid range
check_position_index
Check if a position index is within valid range
check_position_indexes
Check if a position index range is valid
check_state
Check if a state condition is true
check_state_with_message
Check if a state condition is true and provide a custom error message