pub enum ComparisonConstraint {
EqualTo(ArgumentValue),
NotEqualTo(ArgumentValue),
LessThan(ArgumentValue),
AtMost(ArgumentValue),
GreaterThan(ArgumentValue),
AtLeast(ArgumentValue),
}Expand description
A comparison between an argument and a captured scalar value.
Variants
EqualTo(ArgumentValue)
Requires equality with the captured value.
NotEqualTo(ArgumentValue)
Requires inequality with the captured value.
LessThan(ArgumentValue)
Requires a value strictly less than the captured value.
AtMost(ArgumentValue)
Requires a value less than or equal to the captured value.
GreaterThan(ArgumentValue)
Requires a value strictly greater than the captured value.
AtLeast(ArgumentValue)
Requires a value greater than or equal to the captured value.