pub enum IndexRole {
Element,
Position,
}Expand description
The role of an index in an indexed argument operation.
Variants
Element
Identifies an existing element and therefore excludes the collection end.
Position
Identifies an insertion or boundary position, including the collection end.