Condition Argument Validation
Provides general condition validation functionality.
Functions
- check_
argument - Check if an argument condition is true
- check_
argument_ fmt - Check if an argument condition is true and use formatted message
- check_
argument_ with_ message - Check if an argument condition is true and provide a custom error message
- check_
bounds - Check boundary conditions
- check_
element_ index - Check if an index is within valid range
- check_
position_ index - Check if a position index is within valid range
- check_
position_ indexes - Check if a position index range is valid
- check_
state - Check if a state condition is true
- check_
state_ with_ message - Check if a state condition is true and provide a custom error message