pub struct RangeConstraint { /* private fields */ }Expand description
A numeric range with independently inclusive, exclusive, or absent bounds.
Implementations
Sourceimpl RangeConstraint
impl RangeConstraint
Sourcepub fn new(lower: ArgumentBound, upper: ArgumentBound) -> Self
pub fn new(lower: ArgumentBound, upper: ArgumentBound) -> Self
Creates a range from its lower and upper bounds.
The bounds are retained exactly as supplied and are not ordered or otherwise validated.
Sourcepub fn lower(&self) -> &ArgumentBound
pub fn lower(&self) -> &ArgumentBound
Returns the lower bound of this range.
Sourcepub fn upper(&self) -> &ArgumentBound
pub fn upper(&self) -> &ArgumentBound
Returns the upper bound of this range.
Sourcepub fn into_bounds(self) -> (ArgumentBound, ArgumentBound)
pub fn into_bounds(self) -> (ArgumentBound, ArgumentBound)
Consumes this range and returns its lower and upper bounds.
The first tuple element is the lower bound and the second is the upper bound.